<?php
/* --------------------------------------------------------------
   GambioHubUpdaterController.inc.php 2017-09-28
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

MainFactory::load_class('AdminHttpViewController');

/**
 * Class HubConnectorUpdaterController
 */
class HubConnectorUpdaterController extends AdminHttpViewController
{
	/**
	 * @var HubConnectorUpdater
	 */
	private $hubConnectorUpdater;
	
	/**
	 * @var messageStack
	 */
	private $messageStack;
	
	/**
	 * @var LanguageTextManager
	 */
	private $textPhrases;
	
	
	/**
	 * Initial method for this controller.
	 */
	public function init()
	{
		global $messageStack;
		
		$this->hubConnectorUpdater = MainFactory::create('HubConnectorUpdater');
		$this->messageStack        = $messageStack;
		$this->textPhrases         = MainFactory::create('LanguageTextManager', 'hub_connector_updater',
		                                                 $_SESSION['languages_id']);
	}
	
	
	/**
	 * Default action.
	 * Shows the current and available version and also all available updates.
	 *
	 * @return AdminLayoutHttpControllerResponse
	 */
	public function actionDefault()
	{
		$title    = new NonEmptyStringType($this->textPhrases->get_text('PAGE_TITLE'));
		$template = new ExistingFile(new NonEmptyStringType(DIR_FS_ADMIN
		                                                    . '/html/content/hub_connector_updater/overview.html'));
		
		$data = MainFactory::create('KeyValueCollection', [
			'updateStatus'         => $this->hubConnectorUpdater->getUpdatesStatus(),
			'downloadedUpdates'    => $this->hubConnectorUpdater->getDownloadedUpdates(),
			'downloadBeforeUpdate' => $this->hubConnectorUpdater->getDownloadBeforeUpdate(),
		]);
		
		return MainFactory::create('AdminLayoutHttpControllerResponse', $title, $template, $data);
	}
	
	
	/**
	 * Download updates action.
	 * Downloads all available updates and redirects to the default page.
	 *
	 * @return RedirectHttpControllerResponse
	 */
	public function actionDownloadUpdates()
	{
		try
		{
			$this->hubConnectorUpdater->downloadUpdates();
		}
		catch(Exception $e)
		{
			if($e instanceof HubConnectorUpdaterServerNotAvailableException)
			{
				$this->messageStack->add_session($e->getMessage(), 'error');
			}
			elseif($e instanceof HubConnectorUpdaterNoUpdateAvailableException)
			{
				$this->messageStack->add_session($e->getMessage(), 'info');
			}
			elseif($e instanceof HubConnectorUpdaterDownloadFailedException === false)
			{
				throw $e;
			}
		}
		
		return MainFactory::create('RedirectHttpControllerResponse', 'admin.php?do=HubConnectorUpdater');
	}
	
	
	/**
	 * Install updates action.
	 * May download all available updates and unzips them. Checks the file permissions and copy the files into the shop.
	 *
	 * @return RedirectHttpControllerResponse
	 */
	public function actionInstallUpdates()
	{
		try
		{
			$this->hubConnectorUpdater->installUpdates();
		}
		catch(Exception $e)
		{
			if($e instanceof HubConnectorUpdaterServerNotAvailableException
			   || $e instanceof HubConnectorUpdaterNoInitialPointException
			   || $e instanceof HubConnectorUpdaterBackupRestoreFailedException
			   || $e instanceof HubConnectorUpdaterUpdateFailedException
			)
			{
				$this->messageStack->add_session($e->getMessage(), 'error');
			}
			elseif($e instanceof HubConnectorUpdaterNoUpdateAvailableException)
			{
				$this->messageStack->add_session($e->getMessage(), 'info');
			}
			elseif($e instanceof HubConnectorUpdaterDownloadFailedException === false
			       && $e instanceof HubConnectorUpdaterBackupCreationFailedException === false
			)
			{
				throw $e;
			}
		}
		
		return MainFactory::create('RedirectHttpControllerResponse', 'admin.php?do=HubConnectorUpdater');
	}
}